<?php
/*
 * Tutorial: Cómo registrar un tipo personalizado de artículo en WordPress
 * URL: https://www.rafaelcardero.com/es/tutoriales/como-registrar-un-tipo-personalizado-de-articulo-en-wordpress/
 */

/* -----------------------------------------------------------------------------
 * - Ejemplo
 * ---------------------------------------------------------------------------*/
 
/*
 * Registers the custom post type Book.
 */
function ns_register_book_cpt(){
    
    // See all possible labels in the PHPDoc of the function get_post_type_labels
    $labels = array(
       'name'                  => __('Books', 'ns'),
       'singular_name'         => __('Book', 'ns'),
       'menu_name'             => __('Books', 'ns'),
       'all_items'             => __('All Books', 'ns'),
       'add_new'               => __('Add New', 'ns'),
       'add_new_item'          => __('Add New Book', 'ns'),
       'edit_item'             => __('Edit Book', 'ns'),
       'new_item'              => __('New Book', 'ns'),
       'view_item'             => __('View Book', 'ns'),
       'view_items'            => __('View Books', 'ns'),
       'search_items'          => __('Search Books', 'ns'),
       'not_found'             => __('No books found.', 'ns'),
       'not_found_in_trash'    => __('No books found in Trash.', 'ns'),
       'archives'              => __('Book Archives', 'ns'),
       'filter_items_list'     => __('Filter books list', 'ns'),
       'items_list_navigation' => __('Books list navigation', 'ns'),
       'items_list'            => __('Books list', 'ns')
    );
    
    // See all possible attributes in the PHPDoc of the function register_post_type
    $args = array(
        'label'                 => __('Books', 'ns'),
        'labels'                => $labels, 
        'public'                => true,
        'exclude_from_search'   => false,
        'publicly_queryable'    => true,
        'show_ui'               => true,
        'show_in_nav_menus'     => true,
        'show_in_menu'          => true,
        'show_in_admin_bar'     => true,
        'hierarchical'          => false,
        'supports'              => array('title', 'editor', 'author'), 
        'taxonomies'            => array('post_tag'),
        'has_archive'           => true, 
        'rewrite'               => array('slug' => 'books'),
        'query_var'             => 'book'
    );
    
    register_post_type('ns_book_cpt', $args);
}
add_action('init', 'ns_register_book_cpt', 10, 0);

/* -----------------------------------------------------------------------------
 * - Ejercicio
 * ---------------------------------------------------------------------------*/

/*
 * Registers the custom post type Movie.
 */
function ns_register_movie_cpt(){
    
    // See all possible labels in the PHPDoc of the function get_post_type_labels
    $labels = array(
       'name'                  => __('Movies', 'ns'),
       'singular_name'         => __('Movie', 'ns'),
       'menu_name'             => __('Movies', 'ns'),
       'all_items'             => __('All Movies', 'ns'),
       'add_new'               => __('Add New', 'ns'),
       'add_new_item'          => __('Add New Movie', 'ns'),
       'edit_item'             => __('Edit Movie', 'ns'),
       'new_item'              => __('New Movie', 'ns'),
       'view_item'             => __('View Movie', 'ns'),
       'view_items'            => __('View Movies', 'ns'),
       'search_items'          => __('Search Movies', 'ns'),
       'not_found'             => __('No movies found.', 'ns'),
       'not_found_in_trash'    => __('No movies found in Trash.', 'ns'),
       'archives'              => __('Movie Archives', 'ns'),
       'filter_items_list'     => __('Filter movies list', 'ns'),
       'items_list_navigation' => __('Movies list navigation', 'ns'),
       'items_list'            => __('Movies list', 'ns')
    );
    
    // See all possible attributes in the PHPDoc of the function register_post_type
    $args = array(
        'label'                 => __('Movies', 'ns'),
        'labels'                => $labels, 
        'public'                => true,
        'exclude_from_search'   => false,
        'publicly_queryable'    => true,
        'show_ui'               => true,
        'show_in_nav_menus'     => true,
        'show_in_menu'          => true,
        'show_in_admin_bar'     => true,
        'hierarchical'          => false,
        'supports'              => array('title', 'editor', 'excerpt', 'author', 'revisions'), 
        'taxonomies'            => array('post_tag', 'category'),
        'has_archive'           => true, 
        'rewrite'               => array('slug' => 'movies'),
        'query_var'             => 'movie'
    );
    
    register_post_type('ns_movie_cpt', $args);
}
add_action('init', 'ns_register_movie_cpt', 10, 0);